History
=======

0.0.3 (7/10/2013)
-----------------

- Fixed issue with validation continuing even after failure.
- Implemented a very basic set of tests.

0.0.2 (7/10/2013)
-----------------

- Flask Specific Model Validation.

0.0.1 (7/10/2013)
-----------------

- Conception.
- Initial Commit of Package to GitHub.
- First Release.